// Copyright 2019 gRPC authors.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

syntax = "proto3";

package grpc.testing;

import "grpc/testing/package_options_import.proto";
import "grpc/testing/package_options_import2.proto";

// For sanity checking package definitions
option ruby_package = "RPC::Test::New::Package::Options";

message AnotherTestRequest { }

message AnotherTestResponse { }

message Foo { }

message Bar {
  message Baz { }
}

service AnotherTestService {
  rpc GetTest(AnotherTestRequest) returns (AnotherTestResponse) { }
  rpc OtherTest(Thing) returns (Thing) { }
  rpc PackageTest(grpc.testing.Thing) returns (grpc.foo.Foo.Bar) { }
  rpc FooTest(Foo) returns (Foo) { }
  rpc NestedMessageTest(Foo) returns (Bar.Baz) { }
}
